==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/ta-IN/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'பெரும்பங்கு சொத்துக்களை நீக்குவதை உறுதிப்படுத்தவும்',
    'bulk_restore'      => 'Confirm Bulk Restore Assets', 
  'bulk_delete_help'	=> 'கீழே மொத்த நீக்குவதற்கான சொத்துக்களை மதிப்பாய்வு செய்யவும். நீக்கப்பட்டவுடன், இந்த சொத்துகள் மீட்டமைக்கப்படலாம், ஆனால் அவை தற்போது எந்த பயனர்களையும் தற்போது ஒதுக்கப்படும்.',
  'bulk_restore_help'	=> 'Review the assets for bulk restoration below. Once restored, these assets will not be associated with any users they were previously assigned to.',
  'bulk_delete_warn'	=> 'நீங்கள் நீக்குவது: asset_count சொத்துகள்.',
  'bulk_restore_warn'	=> 'You are about to restore :asset_count assets.',
    'bulk_update'		=> 'மொத்த புதுப்பித்தல் சொத்துகள்',
    'bulk_update_help'	=> 'இந்த படிவம் ஒரே நேரத்தில் பல சொத்துக்களை புதுப்பிக்க உதவுகிறது. நீங்கள் மாற்ற வேண்டிய துறைகள் மட்டுமே நிரப்பவும். காலியாக உள்ள எந்த புலமும் மாறாமல் இருக்கும்.',
    'bulk_update_warn'	=> 'You are about to edit the properties of a single asset.|You are about to edit the properties of :asset_count assets.',
    'bulk_update_with_custom_field' => 'Note the assets are :asset_model_count different types of models.',
    'bulk_update_model_prefix' => 'On Models', 
    'bulk_update_custom_field_unique' => 'This is a unique field and can not be bulk edited.',
    'checkedout_to'		=> 'அவுட் சரிபார்க்கப்பட்டது',
    'checkout_date'		=> 'புதுப்பிப்பு தேதி',
    'checkin_date'		=> 'சரி தேதி',
    'checkout_to'		=> 'புதுப்பித்தல்',
    'cost'				=> 'கொள்முதல் செலவு',
    'create'			=> 'சொத்து உருவாக்கவும்',
    'date'				=> 'கொள்முதல் தேதி',
    'depreciation'	    => 'தேய்மானம்',
    'depreciates_on'	=> 'நிக்காது',
    'default_location'	=> 'இயல்புநிலை இருப்பிடம்',
    'default_location_phone' => 'Default Location Phone',
    'eol_date'			=> 'EOL தேதி',
    'eol_rate'			=> 'EOL விகிதம்',
    'expected_checkin'  => 'எதிர்பார்த்த செக்கின் தேதி',
    'expires'			=> 'காலாவதியாகிறது',
    'fully_depreciated'	=> 'முற்றிலும் குறைத்து மதிப்பிடப்பட்டுள்ளது',
    'help_checkout'		=> 'நீங்கள் உடனடியாக இந்த சொத்தை ஒதுக்க விரும்பினால், மேலேயுள்ள நிலை பட்டியலில் இருந்து "வரிசைப்படுத்துவதற்குத் தயார்" என்பதைத் தேர்ந்தெடுக்கவும்.',
    'mac_address'		=> 'Mac முகவரி',
    'manufacturer'		=> 'உற்பத்தியாளர்',
    'model'				=> 'மாதிரி',
    'months'			=> 'மாதங்கள்',
    'name'				=> 'சொத்து பெயர்',
    'notes'				=> 'குறிப்புக்கள்',
    'order'				=> 'ஆர்டர் எண்',
    'qr'				=> 'க்யு ஆர் குறியீடு',
    'requestable'		=> 'பயனர்கள் இந்த சொத்தை கோரலாம்',
    'redirect_to_all'   => 'Return to all :type',
    'redirect_to_type'   => 'Go to :type',
    'redirect_to_checked_out_to'   => 'Go to Checked Out to',
    'select_statustype'	=> 'நிலை வகை தேர்ந்தெடுக்கவும்',
    'serial'			=> 'சீரியல்',
    'status'			=> 'நிலைமை',
    'tag'				=> 'சொத்து டேக்',
    'update'			=> 'சொத்து புதுப்பிப்பு',
    'warranty'			=> 'உத்தரவாதத்தை',
        'warranty_expires'		=> 'Warranty Expires',
    'years'				=> 'ஆண்டுகள்',
    'asset_location' => 'Update Asset Location',
    'asset_location_update_default_current' => 'Update default location AND actual location',
    'asset_location_update_default' => 'Update only default location',
    'asset_location_update_actual' => 'Update only actual location',
    'asset_not_deployable' => 'That asset status is not deployable. This asset cannot be checked out.',
    'asset_not_deployable_checkin' => 'That asset status is not deployable. Using this status label will checkin the asset.',
    'asset_deployable' => 'That status is deployable. This asset can be checked out.',
    'processing_spinner' => 'Processing... (This might take a bit of time on large files)',
    'optional_infos'  => 'Optional Information',
    'order_details'   => 'Order Related Information'
];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/ta-IN/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'பெரும்பங்கு சொத்துக்களை நீக்குவதை உறுதிப்படுத்தவும்',
    'bulk_restore'      => 'Confirm Bulk Restore Assets', 
  'bulk_delete_help'	=> 'கீழே மொத்த நீக்குவதற்கான சொத்துக்களை மதிப்பாய்வு செய்யவும். நீக்கப்பட்டவுடன், இந்த சொத்துகள் மீட்டமைக்கப்படலாம், ஆனால் அவை தற்போது எந்த பயனர்களையும் தற்போது ஒதுக்கப்படும்.',
  'bulk_restore_help'	=> 'Review the assets for bulk restoration below. Once restored, these assets will not be associated with any users they were previously assigned to.',
  'bulk_delete_warn'	=> 'நீங்கள் நீக்குவது: asset_count சொத்துகள்.',
  'bulk_restore_warn'	=> 'You are about to restore :asset_count assets.',
    'bulk_update'		=> 'மொத்த புதுப்பித்தல் சொத்துகள்',
    'bulk_update_help'	=> 'இந்த படிவம் ஒரே நேரத்தில் பல சொத்துக்களை புதுப்பிக்க உதவுகிறது. நீங்கள் மாற்ற வேண்டிய துறைகள் மட்டுமே நிரப்பவும். காலியாக உள்ள எந்த புலமும் மாறாமல் இருக்கும்.',
    'bulk_update_warn'	=> 'You are about to edit the properties of a single asset.|You are about to edit the properties of :asset_count assets.',
    'bulk_update_with_custom_field' => 'Note the assets are :asset_model_count different types of models.',
    'bulk_update_model_prefix' => 'On Models', 
    'bulk_update_custom_field_unique' => 'This is a unique field and can not be bulk edited.',
    'checkedout_to'		=> 'அவுட் சரிபார்க்கப்பட்டது',
    'checkout_date'		=> 'புதுப்பிப்பு தேதி',
    'checkin_date'		=> 'சரி தேதி',
    'checkout_to'		=> 'புதுப்பித்தல்',
    'cost'				=> 'கொள்முதல் செலவு',
    'create'			=> 'சொத்து உருவாக்கவும்',
    'date'				=> 'கொள்முதல் தேதி',
    'depreciation'	    => 'தேய்மானம்',
    'depreciates_on'	=> 'நிக்காது',
    'default_location'	=> 'இயல்புநிலை இருப்பிடம்',
    'default_location_phone' => 'Default Location Phone',
    'eol_date'			=> 'EOL தேதி',
    'eol_rate'			=> 'EOL விகிதம்',
    'expected_checkin'  => 'எதிர்பார்த்த செக்கின் தேதி',
    'expires'			=> 'காலாவதியாகிறது',
    'fully_depreciated'	=> 'முற்றிலும் குறைத்து மதிப்பிடப்பட்டுள்ளது',
    'help_checkout'		=> 'நீங்கள் உடனடியாக இந்த சொத்தை ஒதுக்க விரும்பினால், மேலேயுள்ள நிலை பட்டியலில் இருந்து "வரிசைப்படுத்துவதற்குத் தயார்" என்பதைத் தேர்ந்தெடுக்கவும்.',
    'mac_address'		=> 'Mac முகவரி',
    'manufacturer'		=> 'உற்பத்தியாளர்',
    'model'				=> 'மாதிரி',
    'months'			=> 'மாதங்கள்',
    'name'				=> 'சொத்து பெயர்',
    'notes'				=> 'குறிப்புக்கள்',
    'order'				=> 'ஆர்டர் எண்',
    'qr'				=> 'க்யு ஆர் குறியீடு',
    'requestable'		=> 'பயனர்கள் இந்த சொத்தை கோரலாம்',
    'redirect_to_all'   => 'Return to all :type',
    'redirect_to_type'   => 'Go to :type',
    'redirect_to_checked_out_to'   => 'Go to Checked Out to',
    'select_statustype'	=> 'நிலை வகை தேர்ந்தெடுக்கவும்',
    'serial'			=> 'சீரியல்',
    'status'			=> 'நிலைமை',
    'tag'				=> 'சொத்து டேக்',
    'update'			=> 'சொத்து புதுப்பிப்பு',
    'warranty'			=> 'உத்தரவாதத்தை',
        'warranty_expires'		=> 'Warranty Expires',
    'years'				=> 'ஆண்டுகள்',
    'asset_location' => 'Update Asset Location',
    'asset_location_update_default_current' => 'Update default location AND actual location',
    'asset_location_update_default' => 'Update only default location',
    'asset_location_update_actual' => 'Update only actual location',
    'asset_not_deployable' => 'That asset status is not deployable. This asset cannot be checked out.',
    'asset_not_deployable_checkin' => 'That asset status is not deployable. Using this status label will checkin the asset.',
    'asset_deployable' => 'That status is deployable. This asset can be checked out.',
    'processing_spinner' => 'Processing... (This might take a bit of time on large files)',
    'optional_infos'  => 'Optional Information',
    'order_details'   => 'Order Related Information',
    'calc_eol'    => 'If nulling the EOL date, use automatic EOL calculation based on the purchase date and EOL rate.',
];
